==> vtk-v3.1.1.zip: vtk-v3.1.1/patented/vtkKitwareObjectFactory.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkKitwareObjectFactory.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2000 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#include "vtkKitwareObjectFactory.h"
#include "vtkKitwareContourFilter.h"
#include "vtkVersion.h"

void vtkKitwareObjectFactory::PrintSelf(ostream& os, vtkIndent indent)
{
  os << indent << "Kitware object factory" << endl;
}


vtkObject* vtkKitwareObjectFactory::CreateObject(const char* vtkclassname )
{
  // This should be a hash table, but for now use strcmp
  if(strcmp(vtkclassname, "vtkContourFilter") == 0)
    {
    return vtkKitwareContourFilter::New();
    }
  return 0;
}

const char* vtkKitwareObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}


extern "C" vtkObjectFactory* vtkLoad()
{
  return vtkKitwareObjectFactory::New();
}

==> vtk-v3.2.0.zip: vtk-v3.2.0/patented/vtkKitwareObjectFactory.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkKitwareObjectFactory.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2001 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#include "vtkKitwareObjectFactory.h"
#include "vtkKitwareContourFilter.h"
#include "vtkVersion.h"

void vtkKitwareObjectFactory::PrintSelf(ostream& os, vtkIndent indent)
{
  os << indent << "Kitware object factory" << endl;
}


vtkObject* vtkKitwareObjectFactory::CreateObject(const char* vtkclassname )
{
  // This should be a hash table, but for now use strcmp
  if(strcmp(vtkclassname, "vtkContourFilter") == 0)
    {
    return vtkKitwareContourFilter::New();
    }
  return 0;
}

const char* vtkKitwareObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}


extern "C" vtkObjectFactory* vtkLoad()
{
  return vtkKitwareObjectFactory::New();
}
